# ViralClassificationAWS
Amazon SageMaker project for viral classification in metagenomic sequence data of mosquitoes. 

# torchmetagen

The torchmetagen package consists of dataset formatter, model architectures and common sequence transformations for metagenomic sequences classification.

# Installation

From source:

```
UNDER CONSTRUCTION 

```

# Dataset format

Torchmetagen supports the following fasta-like files: 
-   .fasta (default)
-   .fa 
-   .faa 
-   .fna
-   .fsa
